define(
//begin v1.x content
{
	"HKD_displayName": "דולר הונג קונגי",
	"CNY_displayName": "יואן סיני",
	"JPY_displayName": "ין יפני",
	"JPY_symbol": "¥",
	"USD_displayName": "דולר אמריקאי",
	"CAD_symbol": "CA$",
	"GBP_displayName": "לירה שטרלינג",
	"CHF_displayName": "פרנק שוויצרי",
	"CNY_symbol": "‎CN¥‎",
	"EUR_displayName": "אירו",
	"GBP_symbol": "£",
	"CAD_displayName": "דולר קנדי",
	"USD_symbol": "$",
	"EUR_symbol": "€",
	"AUD_displayName": "דולר אוסטרלי",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "A$"
}
//end v1.x content
);